@@ -15,11 +15,11 @@ C<Math::Geometry::Construction::Line> - line through two points
 
 =head1 VERSION
 
-Version 0.004
+Version 0.006
 
 =cut
 
-our $VERSION = '0.004';
+our $VERSION = '0.006';
 
 
 ###########################################################################
@@ -39,17 +39,16 @@ sub id_template { return $ID_TEMPLATE }
 ###########################################################################
 
 with 'Math::Geometry::Construction::Object';
-with 'Math::Geometry::Construction::PointSelection';
+with 'Math::Geometry::Construction::PositionSelection';
 with 'Math::Geometry::Construction::Output';
 
-has 'support'     => (isa     => 'ArrayRef[Item]',
-		      is      => 'bare',
-		      traits  => ['Array'],
-		      default => sub { [] },
-		      handles => {count_support  => 'count',
-				  support        => 'elements',
-				  single_support => 'accessor',
-				  add_support    => 'push'});
+has 'support'     => (isa      => 'ArrayRef[Item]',
+		      is       => 'bare',
+		      traits   => ['Array'],
+		      required => 1,
+		      handles  => {count_support  => 'count',
+				   support        => 'elements',
+				   single_support => 'accessor'});
 
 has 'extend'      => (isa     => 'Num',
 		      is      => 'rw',
@@ -73,6 +72,12 @@ sub points {
     return($self->support, $self->points_of_interest);
 }
 
+sub positions {
+    my ($self) = @_;
+
+    return map { $_->position } $self->points;
+}
+
 sub as_svg {
     my ($self, %args) = @_;
     return undef if $self->hidden;
@@ -83,13 +88,6 @@ sub as_svg {
 	return undef;
     }
 
-    # check for defined points
-    if(any { !defined($_) } @support) {
-	warn sprintf("Undefined support point in line %s, ".
-		     "nothing to draw.\n", $self->id);
-	return undef;
-    }
-
     my @support_positions = map { $_->position } @support;
 
     # check for defined positions
@@ -99,15 +97,14 @@ sub as_svg {
 	return undef;
     }
 
-    my $direction         =
-	($support_positions[1] - $support_positions[0])->norm;
+    my $direction = ($support_positions[1] - $support_positions[0])->norm;
 
     # I don't need to check for defined points here because at least
     # the support points are there and will show up as extremes.
-    my @positions         = ($self->extreme_point($direction)->position
-			     + $direction * $self->extend,
-			     $self->extreme_point(-$direction)->position
-			     - $direction * $self->extend);
+    my @positions = ($self->extreme_position($direction)
+		     + $direction * $self->extend,
+		     $self->extreme_position(-$direction)
+		     - $direction * $self->extend);
 
     $args{parent}->line(x1    => $positions[0]->x,
 			y1    => $positions[0]->y,
